#include "branchpropwindow.h"

#include <QColorDialog>

#include "frameobj.h"


BranchPropertyWindow::BranchPropertyWindow (QWidget *parent):QDialog(parent)
{
	ui.setupUi (this);

	branch=NULL;
	mapEditor=NULL;

	ui.tabWidget->setEnabled(false);

	penColor=QColor (Qt::black);
	brushColor=QColor (Qt::black);
    QPixmap pix( 16,16);
    pix.fill (penColor);
	ui.framePenColorButton->setPixmap (pix);
	ui.frameBrushColorButton->setPixmap (pix);

	connect ( 
		ui.framePenColorButton, SIGNAL (clicked()), 
		this, SLOT (framePenColorClicked()));
	connect ( 
		ui.frameBrushColorButton, SIGNAL (clicked()), 
		this, SLOT (frameBrushColorClicked()));
	connect ( 
		ui.frameTypeCombo, SIGNAL (currentIndexChanged( int)), 
		this, SLOT (frameTypeChanged (int)));
	connect ( 
		ui.hideLinkIfUnselected, SIGNAL (stateChanged( int)), 
		this, SLOT (linkHideUnselectedChanged (int)));
}

void BranchPropertyWindow::setBranch (BranchObj *bo)
{
	branch=bo;
	if (bo) 
	{
		ui.tabWidget->setEnabled (true);

		// Frame
		FrameType t=branch->getFrameType();
		if (t==NoFrame)
		{
			ui.frameTypeCombo->setCurrentIndex (0);
			penColor=Qt::white;
			brushColor=Qt::white;
			ui.colorGroupBox->setEnabled (false);
		} else	
		{
			penColor=bo->getFramePenColor();
			brushColor=bo->getFrameBrushColor();
			QPixmap pix( 16,16);
			pix.fill (penColor);
			ui.frameBrushColorButton->setPixmap (pix);
			pix.fill (brushColor);
			ui.frameBrushColorButton->setPixmap (pix);
			ui.colorGroupBox->setEnabled (true);

			switch (t)
			{
				case Rectangle: 
					ui.frameTypeCombo->setCurrentIndex (1);
					break;
				case Ellipse: 
					ui.frameTypeCombo->setCurrentIndex (2);
					break;
				default: 
					break;
			}
		}	
		
		// Link
		if (branch->getHideLinkUnselected())
			ui.hideLinkIfUnselected->setCheckState (Qt::Checked);
		else	
			ui.hideLinkIfUnselected->setCheckState (Qt::Unchecked);
	} else
	{
		ui.tabWidget->setEnabled (false);
	}
}

void BranchPropertyWindow::setMapEditor (MapEditor *me)
{
	mapEditor=me;
	if (mapEditor) 
		setBranch (mapEditor->getSelectedBranch() );
	else
		ui.tabWidget->setEnabled (false);
		
}

void BranchPropertyWindow::frameTypeChanged (int i)
{
	if (mapEditor)
		switch (i)
		{
			case 0: mapEditor->setFrameType (NoFrame); break;
			case 1: mapEditor->setFrameType (Rectangle); break;
			case 2: mapEditor->setFrameType (Ellipse); break;
		}
}

void BranchPropertyWindow::framePenColorClicked()
{
	if (mapEditor) 
	{	
		QColor col = QColorDialog::getColor( penColor, this );
		if ( col.isValid() ) 
		{
			penColor=col;
			mapEditor->setFramePenColor (penColor);
		}	
	}
}

void BranchPropertyWindow::frameBrushColorClicked()
{
	if (mapEditor) 
	{
		QColor col = QColorDialog::getColor( brushColor, this );
		if ( col.isValid() ) 
		{
			brushColor=col;
			mapEditor->setFrameBrushColor (brushColor);
		}	
	}	
}

void BranchPropertyWindow::linkHideUnselectedChanged (int i)
{
	if (!branch) return;
	branch->setHideLinkUnselected(i);
}

